@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: datetime.lisp 8595 2004-02-03 18:32:40Z kevin $
+;;;; $Id: datetime.lisp 10081 2004-10-03 07:15:20Z kevin $
 ;;;;
 ;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -74,6 +74,9 @@
 (defun posix-time-to-utime (time)
   (+ time +posix-epoch+))
 
+(defun utime-to-posix-time (utime)
+  (- utime +posix-epoch+))
+
 ;; Monthnames taken from net-telent-date to support lml2
 
 (defvar *monthnames*
@@ -89,7 +92,7 @@
     (10 . "October")
     (11 . "November")
     (12 . "December")))
-    
+
 (defun monthname (stream arg colon-p at-p &optional width (mincol 0) (colinc 1) (minpad 0) (padchar #\Space))
   "Print the name of the month (1=January) corresponding to ARG on STREAM.  This is intended for embedding in a FORMAT directive: WIDTH governs the number of characters of text printed, MINCOL, COLINC, MINPAD, PADCHAR work as for ~A"
   (let ((monthstring (cdr (assoc arg *monthnames*))))
