@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Jul 2003
 ;;;;
-;;;; $Id: os.lisp 9086 2004-04-19 06:32:34Z kevin $
+;;;; $Id: os.lisp 10042 2004-09-28 06:20:21Z kevin $
 ;;;;
 ;;;; *************************************************************************
 
@@ -60,7 +60,8 @@ returns (VALUES string-output error-output exit-status)"
 	  (let ((status 
 		 (system:call-system-showing-output
 		  command
-		  :shell-type "/bin/sh"
+		  :prefix ""
+		  :show-cmd nil
 		  :output-stream output)))
 	    (values (get-output-stream-string output) nil status))
 	(close output)))
@@ -119,7 +120,9 @@ returns (VALUES output-string pid)"
     (system:call-system-showing-output
      command
      :shell-type "/bin/sh"
-     :output-stream output)
+     :show-cmd nil
+     :prefix ""
+     :output-stream nil)
     
     #+clisp		;XXX not exactly *verbose-out*, I know
     (ext:run-shell-command  command :output :terminal :wait t)
@@ -135,3 +138,24 @@ returns (VALUES output-string pid)"
     (error "RUN-SHELL-PROGRAM not implemented for this Lisp")
 
     ))
+
+(defun delete-directory-and-files (dir &key (if-does-not-exist :error) (quiet t) force)
+  #+allegro (excl:delete-directory-and-files dir :if-does-not-exist if-does-not-exist
+					     :quiet quiet :force force)
+  #-(or allegro) (declare (ignore force))
+  #-(or allegro) (cond
+		   ((probe-directory dir)
+		    (let ((cmd (format nil "rm -rf ~A" (namestring dir))))
+		      (unless quiet
+			(format *trace-output* ";; ~A" cmd))
+		      (command-output cmd)))
+		   ((eq if-does-not-exist :error)
+		    (error "Directory ~A does not exist [delete-directory-and-files]." dir))))
+
+(defun file-size (file)
+  (when (probe-file file)
+    #+allegro (let ((stat (excl.osi:stat (namestring file))))
+		(excl.osi:stat-size stat))
+    #-allegro
+    (with-open-file (in file :direction :input)
+      (file-length in))))
